# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .exadata_insight import ExadataInsight
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EmManagedExternalExadataInsight(ExadataInsight):
    """
    EM-managed Exadata insight resource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EmManagedExternalExadataInsight object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.EmManagedExternalExadataInsight.entity_source` attribute
        of this class is ``EM_MANAGED_EXTERNAL_EXADATA`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_source:
            The value to assign to the entity_source property of this EmManagedExternalExadataInsight.
            Allowed values for this property are: "EM_MANAGED_EXTERNAL_EXADATA"
        :type entity_source: str

        :param id:
            The value to assign to the id property of this EmManagedExternalExadataInsight.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this EmManagedExternalExadataInsight.
        :type compartment_id: str

        :param exadata_name:
            The value to assign to the exadata_name property of this EmManagedExternalExadataInsight.
        :type exadata_name: str

        :param exadata_display_name:
            The value to assign to the exadata_display_name property of this EmManagedExternalExadataInsight.
        :type exadata_display_name: str

        :param exadata_type:
            The value to assign to the exadata_type property of this EmManagedExternalExadataInsight.
            Allowed values for this property are: "DBMACHINE", "EXACS", "EXACC"
        :type exadata_type: str

        :param exadata_rack_type:
            The value to assign to the exadata_rack_type property of this EmManagedExternalExadataInsight.
            Allowed values for this property are: "FULL", "HALF", "QUARTER", "EIGHTH"
        :type exadata_rack_type: str

        :param is_virtualized_exadata:
            The value to assign to the is_virtualized_exadata property of this EmManagedExternalExadataInsight.
        :type is_virtualized_exadata: bool

        :param status:
            The value to assign to the status property of this EmManagedExternalExadataInsight.
            Allowed values for this property are: "DISABLED", "ENABLED", "TERMINATED"
        :type status: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this EmManagedExternalExadataInsight.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this EmManagedExternalExadataInsight.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this EmManagedExternalExadataInsight.
        :type system_tags: dict(str, dict(str, object))

        :param time_created:
            The value to assign to the time_created property of this EmManagedExternalExadataInsight.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this EmManagedExternalExadataInsight.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this EmManagedExternalExadataInsight.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this EmManagedExternalExadataInsight.
        :type lifecycle_details: str

        :param enterprise_manager_identifier:
            The value to assign to the enterprise_manager_identifier property of this EmManagedExternalExadataInsight.
        :type enterprise_manager_identifier: str

        :param enterprise_manager_entity_name:
            The value to assign to the enterprise_manager_entity_name property of this EmManagedExternalExadataInsight.
        :type enterprise_manager_entity_name: str

        :param enterprise_manager_entity_type:
            The value to assign to the enterprise_manager_entity_type property of this EmManagedExternalExadataInsight.
        :type enterprise_manager_entity_type: str

        :param enterprise_manager_entity_identifier:
            The value to assign to the enterprise_manager_entity_identifier property of this EmManagedExternalExadataInsight.
        :type enterprise_manager_entity_identifier: str

        :param enterprise_manager_entity_display_name:
            The value to assign to the enterprise_manager_entity_display_name property of this EmManagedExternalExadataInsight.
        :type enterprise_manager_entity_display_name: str

        :param enterprise_manager_bridge_id:
            The value to assign to the enterprise_manager_bridge_id property of this EmManagedExternalExadataInsight.
        :type enterprise_manager_bridge_id: str

        :param is_auto_sync_enabled:
            The value to assign to the is_auto_sync_enabled property of this EmManagedExternalExadataInsight.
        :type is_auto_sync_enabled: bool

        """
        self.swagger_types = {
            'entity_source': 'str',
            'id': 'str',
            'compartment_id': 'str',
            'exadata_name': 'str',
            'exadata_display_name': 'str',
            'exadata_type': 'str',
            'exadata_rack_type': 'str',
            'is_virtualized_exadata': 'bool',
            'status': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'enterprise_manager_identifier': 'str',
            'enterprise_manager_entity_name': 'str',
            'enterprise_manager_entity_type': 'str',
            'enterprise_manager_entity_identifier': 'str',
            'enterprise_manager_entity_display_name': 'str',
            'enterprise_manager_bridge_id': 'str',
            'is_auto_sync_enabled': 'bool'
        }

        self.attribute_map = {
            'entity_source': 'entitySource',
            'id': 'id',
            'compartment_id': 'compartmentId',
            'exadata_name': 'exadataName',
            'exadata_display_name': 'exadataDisplayName',
            'exadata_type': 'exadataType',
            'exadata_rack_type': 'exadataRackType',
            'is_virtualized_exadata': 'isVirtualizedExadata',
            'status': 'status',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'enterprise_manager_identifier': 'enterpriseManagerIdentifier',
            'enterprise_manager_entity_name': 'enterpriseManagerEntityName',
            'enterprise_manager_entity_type': 'enterpriseManagerEntityType',
            'enterprise_manager_entity_identifier': 'enterpriseManagerEntityIdentifier',
            'enterprise_manager_entity_display_name': 'enterpriseManagerEntityDisplayName',
            'enterprise_manager_bridge_id': 'enterpriseManagerBridgeId',
            'is_auto_sync_enabled': 'isAutoSyncEnabled'
        }

        self._entity_source = None
        self._id = None
        self._compartment_id = None
        self._exadata_name = None
        self._exadata_display_name = None
        self._exadata_type = None
        self._exadata_rack_type = None
        self._is_virtualized_exadata = None
        self._status = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._enterprise_manager_identifier = None
        self._enterprise_manager_entity_name = None
        self._enterprise_manager_entity_type = None
        self._enterprise_manager_entity_identifier = None
        self._enterprise_manager_entity_display_name = None
        self._enterprise_manager_bridge_id = None
        self._is_auto_sync_enabled = None
        self._entity_source = 'EM_MANAGED_EXTERNAL_EXADATA'

    @property
    def enterprise_manager_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_identifier of this EmManagedExternalExadataInsight.
        Enterprise Manager Unique Identifier


        :return: The enterprise_manager_identifier of this EmManagedExternalExadataInsight.
        :rtype: str
        """
        return self._enterprise_manager_identifier

    @enterprise_manager_identifier.setter
    def enterprise_manager_identifier(self, enterprise_manager_identifier):
        """
        Sets the enterprise_manager_identifier of this EmManagedExternalExadataInsight.
        Enterprise Manager Unique Identifier


        :param enterprise_manager_identifier: The enterprise_manager_identifier of this EmManagedExternalExadataInsight.
        :type: str
        """
        self._enterprise_manager_identifier = enterprise_manager_identifier

    @property
    def enterprise_manager_entity_name(self):
        """
        **[Required]** Gets the enterprise_manager_entity_name of this EmManagedExternalExadataInsight.
        Enterprise Manager Entity Name


        :return: The enterprise_manager_entity_name of this EmManagedExternalExadataInsight.
        :rtype: str
        """
        return self._enterprise_manager_entity_name

    @enterprise_manager_entity_name.setter
    def enterprise_manager_entity_name(self, enterprise_manager_entity_name):
        """
        Sets the enterprise_manager_entity_name of this EmManagedExternalExadataInsight.
        Enterprise Manager Entity Name


        :param enterprise_manager_entity_name: The enterprise_manager_entity_name of this EmManagedExternalExadataInsight.
        :type: str
        """
        self._enterprise_manager_entity_name = enterprise_manager_entity_name

    @property
    def enterprise_manager_entity_type(self):
        """
        **[Required]** Gets the enterprise_manager_entity_type of this EmManagedExternalExadataInsight.
        Enterprise Manager Entity Type


        :return: The enterprise_manager_entity_type of this EmManagedExternalExadataInsight.
        :rtype: str
        """
        return self._enterprise_manager_entity_type

    @enterprise_manager_entity_type.setter
    def enterprise_manager_entity_type(self, enterprise_manager_entity_type):
        """
        Sets the enterprise_manager_entity_type of this EmManagedExternalExadataInsight.
        Enterprise Manager Entity Type


        :param enterprise_manager_entity_type: The enterprise_manager_entity_type of this EmManagedExternalExadataInsight.
        :type: str
        """
        self._enterprise_manager_entity_type = enterprise_manager_entity_type

    @property
    def enterprise_manager_entity_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_entity_identifier of this EmManagedExternalExadataInsight.
        Enterprise Manager Entity Unique Identifier


        :return: The enterprise_manager_entity_identifier of this EmManagedExternalExadataInsight.
        :rtype: str
        """
        return self._enterprise_manager_entity_identifier

    @enterprise_manager_entity_identifier.setter
    def enterprise_manager_entity_identifier(self, enterprise_manager_entity_identifier):
        """
        Sets the enterprise_manager_entity_identifier of this EmManagedExternalExadataInsight.
        Enterprise Manager Entity Unique Identifier


        :param enterprise_manager_entity_identifier: The enterprise_manager_entity_identifier of this EmManagedExternalExadataInsight.
        :type: str
        """
        self._enterprise_manager_entity_identifier = enterprise_manager_entity_identifier

    @property
    def enterprise_manager_entity_display_name(self):
        """
        Gets the enterprise_manager_entity_display_name of this EmManagedExternalExadataInsight.
        Enterprise Manager Entity Display Name


        :return: The enterprise_manager_entity_display_name of this EmManagedExternalExadataInsight.
        :rtype: str
        """
        return self._enterprise_manager_entity_display_name

    @enterprise_manager_entity_display_name.setter
    def enterprise_manager_entity_display_name(self, enterprise_manager_entity_display_name):
        """
        Sets the enterprise_manager_entity_display_name of this EmManagedExternalExadataInsight.
        Enterprise Manager Entity Display Name


        :param enterprise_manager_entity_display_name: The enterprise_manager_entity_display_name of this EmManagedExternalExadataInsight.
        :type: str
        """
        self._enterprise_manager_entity_display_name = enterprise_manager_entity_display_name

    @property
    def enterprise_manager_bridge_id(self):
        """
        **[Required]** Gets the enterprise_manager_bridge_id of this EmManagedExternalExadataInsight.
        OPSI Enterprise Manager Bridge OCID


        :return: The enterprise_manager_bridge_id of this EmManagedExternalExadataInsight.
        :rtype: str
        """
        return self._enterprise_manager_bridge_id

    @enterprise_manager_bridge_id.setter
    def enterprise_manager_bridge_id(self, enterprise_manager_bridge_id):
        """
        Sets the enterprise_manager_bridge_id of this EmManagedExternalExadataInsight.
        OPSI Enterprise Manager Bridge OCID


        :param enterprise_manager_bridge_id: The enterprise_manager_bridge_id of this EmManagedExternalExadataInsight.
        :type: str
        """
        self._enterprise_manager_bridge_id = enterprise_manager_bridge_id

    @property
    def is_auto_sync_enabled(self):
        """
        Gets the is_auto_sync_enabled of this EmManagedExternalExadataInsight.
        Set to true to enable automatic enablement and disablement of related targets from Enterprise Manager. New resources (e.g. Database Insights) will be placed in the same compartment as the related Exadata Insight.


        :return: The is_auto_sync_enabled of this EmManagedExternalExadataInsight.
        :rtype: bool
        """
        return self._is_auto_sync_enabled

    @is_auto_sync_enabled.setter
    def is_auto_sync_enabled(self, is_auto_sync_enabled):
        """
        Sets the is_auto_sync_enabled of this EmManagedExternalExadataInsight.
        Set to true to enable automatic enablement and disablement of related targets from Enterprise Manager. New resources (e.g. Database Insights) will be placed in the same compartment as the related Exadata Insight.


        :param is_auto_sync_enabled: The is_auto_sync_enabled of this EmManagedExternalExadataInsight.
        :type: bool
        """
        self._is_auto_sync_enabled = is_auto_sync_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Schedule(object):
    """
    The schedule.
    """

    #: A constant which can be used with the lifecycle_state property of a Schedule.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Schedule.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new Schedule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Schedule.
        :type id: str

        :param name:
            The value to assign to the name property of this Schedule.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Schedule.
        :type compartment_id: str

        :param result_location:
            The value to assign to the result_location property of this Schedule.
        :type result_location: oci.usage_api.models.ResultLocation

        :param schedule_recurrences:
            The value to assign to the schedule_recurrences property of this Schedule.
        :type schedule_recurrences: str

        :param time_scheduled:
            The value to assign to the time_scheduled property of this Schedule.
        :type time_scheduled: datetime

        :param query_properties:
            The value to assign to the query_properties property of this Schedule.
        :type query_properties: oci.usage_api.models.QueryProperties

        :param time_created:
            The value to assign to the time_created property of this Schedule.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Schedule.
            Allowed values for this property are: "ACTIVE", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Schedule.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Schedule.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this Schedule.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'compartment_id': 'str',
            'result_location': 'ResultLocation',
            'schedule_recurrences': 'str',
            'time_scheduled': 'datetime',
            'query_properties': 'QueryProperties',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'compartment_id': 'compartmentId',
            'result_location': 'resultLocation',
            'schedule_recurrences': 'scheduleRecurrences',
            'time_scheduled': 'timeScheduled',
            'query_properties': 'queryProperties',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._name = None
        self._compartment_id = None
        self._result_location = None
        self._schedule_recurrences = None
        self._time_scheduled = None
        self._query_properties = None
        self._time_created = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Schedule.
        The OCID representing unique shedule


        :return: The id of this Schedule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Schedule.
        The OCID representing unique shedule


        :param id: The id of this Schedule.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Schedule.
        The unique name of the schedule created by the user


        :return: The name of this Schedule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Schedule.
        The unique name of the schedule created by the user


        :param name: The name of this Schedule.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Schedule.
        The tenancy of the customer


        :return: The compartment_id of this Schedule.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Schedule.
        The tenancy of the customer


        :param compartment_id: The compartment_id of this Schedule.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def result_location(self):
        """
        **[Required]** Gets the result_location of this Schedule.

        :return: The result_location of this Schedule.
        :rtype: oci.usage_api.models.ResultLocation
        """
        return self._result_location

    @result_location.setter
    def result_location(self, result_location):
        """
        Sets the result_location of this Schedule.

        :param result_location: The result_location of this Schedule.
        :type: oci.usage_api.models.ResultLocation
        """
        self._result_location = result_location

    @property
    def schedule_recurrences(self):
        """
        **[Required]** Gets the schedule_recurrences of this Schedule.
        In x-obmcs-recurring-time format shown here: https://datatracker.ietf.org/doc/html/rfc5545#section-3.3.10
        Describes the frequency of when the schedule will be run


        :return: The schedule_recurrences of this Schedule.
        :rtype: str
        """
        return self._schedule_recurrences

    @schedule_recurrences.setter
    def schedule_recurrences(self, schedule_recurrences):
        """
        Sets the schedule_recurrences of this Schedule.
        In x-obmcs-recurring-time format shown here: https://datatracker.ietf.org/doc/html/rfc5545#section-3.3.10
        Describes the frequency of when the schedule will be run


        :param schedule_recurrences: The schedule_recurrences of this Schedule.
        :type: str
        """
        self._schedule_recurrences = schedule_recurrences

    @property
    def time_scheduled(self):
        """
        **[Required]** Gets the time_scheduled of this Schedule.
        The date and time of the first time job execution


        :return: The time_scheduled of this Schedule.
        :rtype: datetime
        """
        return self._time_scheduled

    @time_scheduled.setter
    def time_scheduled(self, time_scheduled):
        """
        Sets the time_scheduled of this Schedule.
        The date and time of the first time job execution


        :param time_scheduled: The time_scheduled of this Schedule.
        :type: datetime
        """
        self._time_scheduled = time_scheduled

    @property
    def query_properties(self):
        """
        **[Required]** Gets the query_properties of this Schedule.

        :return: The query_properties of this Schedule.
        :rtype: oci.usage_api.models.QueryProperties
        """
        return self._query_properties

    @query_properties.setter
    def query_properties(self, query_properties):
        """
        Sets the query_properties of this Schedule.

        :param query_properties: The query_properties of this Schedule.
        :type: oci.usage_api.models.QueryProperties
        """
        self._query_properties = query_properties

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Schedule.
        The date and time of when the schedule was created


        :return: The time_created of this Schedule.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Schedule.
        The date and time of when the schedule was created


        :param time_created: The time_created of this Schedule.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Schedule.
        The lifecycle state of the schedule

        Allowed values for this property are: "ACTIVE", "INACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Schedule.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Schedule.
        The lifecycle state of the schedule


        :param lifecycle_state: The lifecycle_state of this Schedule.
        :type: str
        """
        allowed_values = ["ACTIVE", "INACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Schedule.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Schedule.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Schedule.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        See `Resource Tags`__. Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Schedule.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Schedule.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Schedule.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Schedule.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__. Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Schedule.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this Schedule.
        Usage of system tag keys. These predefined keys are scoped to namespaces. See `Resource Tags`__. Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this Schedule.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this Schedule.
        Usage of system tag keys. These predefined keys are scoped to namespaces. See `Resource Tags`__. Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this Schedule.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExadataMemberSummary(object):
    """
    Lists name, display name and type of exadata member.
    """

    #: A constant which can be used with the entity_type property of a ExadataMemberSummary.
    #: This constant has a value of "DATABASE"
    ENTITY_TYPE_DATABASE = "DATABASE"

    #: A constant which can be used with the entity_type property of a ExadataMemberSummary.
    #: This constant has a value of "ILOM_SERVER"
    ENTITY_TYPE_ILOM_SERVER = "ILOM_SERVER"

    #: A constant which can be used with the entity_type property of a ExadataMemberSummary.
    #: This constant has a value of "PDU"
    ENTITY_TYPE_PDU = "PDU"

    #: A constant which can be used with the entity_type property of a ExadataMemberSummary.
    #: This constant has a value of "STORAGE_SERVER"
    ENTITY_TYPE_STORAGE_SERVER = "STORAGE_SERVER"

    #: A constant which can be used with the entity_type property of a ExadataMemberSummary.
    #: This constant has a value of "CLUSTER_ASM"
    ENTITY_TYPE_CLUSTER_ASM = "CLUSTER_ASM"

    #: A constant which can be used with the entity_type property of a ExadataMemberSummary.
    #: This constant has a value of "INFINIBAND_SWITCH"
    ENTITY_TYPE_INFINIBAND_SWITCH = "INFINIBAND_SWITCH"

    #: A constant which can be used with the entity_type property of a ExadataMemberSummary.
    #: This constant has a value of "ETHERNET_SWITCH"
    ENTITY_TYPE_ETHERNET_SWITCH = "ETHERNET_SWITCH"

    #: A constant which can be used with the entity_type property of a ExadataMemberSummary.
    #: This constant has a value of "HOST"
    ENTITY_TYPE_HOST = "HOST"

    def __init__(self, **kwargs):
        """
        Initializes a new ExadataMemberSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ExadataMemberSummary.
        :type name: str

        :param display_name:
            The value to assign to the display_name property of this ExadataMemberSummary.
        :type display_name: str

        :param entity_type:
            The value to assign to the entity_type property of this ExadataMemberSummary.
            Allowed values for this property are: "DATABASE", "ILOM_SERVER", "PDU", "STORAGE_SERVER", "CLUSTER_ASM", "INFINIBAND_SWITCH", "ETHERNET_SWITCH", "HOST", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_type: str

        """
        self.swagger_types = {
            'name': 'str',
            'display_name': 'str',
            'entity_type': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'display_name': 'displayName',
            'entity_type': 'entityType'
        }

        self._name = None
        self._display_name = None
        self._entity_type = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ExadataMemberSummary.
        Name of exadata member target


        :return: The name of this ExadataMemberSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExadataMemberSummary.
        Name of exadata member target


        :param name: The name of this ExadataMemberSummary.
        :type: str
        """
        self._name = name

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ExadataMemberSummary.
        Display Name of exadata member target


        :return: The display_name of this ExadataMemberSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ExadataMemberSummary.
        Display Name of exadata member target


        :param display_name: The display_name of this ExadataMemberSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this ExadataMemberSummary.
        Entity type of exadata member target

        Allowed values for this property are: "DATABASE", "ILOM_SERVER", "PDU", "STORAGE_SERVER", "CLUSTER_ASM", "INFINIBAND_SWITCH", "ETHERNET_SWITCH", "HOST", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The entity_type of this ExadataMemberSummary.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this ExadataMemberSummary.
        Entity type of exadata member target


        :param entity_type: The entity_type of this ExadataMemberSummary.
        :type: str
        """
        allowed_values = ["DATABASE", "ILOM_SERVER", "PDU", "STORAGE_SERVER", "CLUSTER_ASM", "INFINIBAND_SWITCH", "ETHERNET_SWITCH", "HOST"]
        if not value_allowed_none_or_none_sentinel(entity_type, allowed_values):
            entity_type = 'UNKNOWN_ENUM_VALUE'
        self._entity_type = entity_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BillingAddress(object):
    """
    Billing address details model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BillingAddress object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param address_key:
            The value to assign to the address_key property of this BillingAddress.
        :type address_key: str

        :param line1:
            The value to assign to the line1 property of this BillingAddress.
        :type line1: str

        :param line2:
            The value to assign to the line2 property of this BillingAddress.
        :type line2: str

        :param city:
            The value to assign to the city property of this BillingAddress.
        :type city: str

        :param country:
            The value to assign to the country property of this BillingAddress.
        :type country: str

        :param postal_code:
            The value to assign to the postal_code property of this BillingAddress.
        :type postal_code: str

        :param state:
            The value to assign to the state property of this BillingAddress.
        :type state: str

        :param email_address:
            The value to assign to the email_address property of this BillingAddress.
        :type email_address: str

        :param company_name:
            The value to assign to the company_name property of this BillingAddress.
        :type company_name: str

        :param first_name:
            The value to assign to the first_name property of this BillingAddress.
        :type first_name: str

        :param last_name:
            The value to assign to the last_name property of this BillingAddress.
        :type last_name: str

        """
        self.swagger_types = {
            'address_key': 'str',
            'line1': 'str',
            'line2': 'str',
            'city': 'str',
            'country': 'str',
            'postal_code': 'str',
            'state': 'str',
            'email_address': 'str',
            'company_name': 'str',
            'first_name': 'str',
            'last_name': 'str'
        }

        self.attribute_map = {
            'address_key': 'addressKey',
            'line1': 'line1',
            'line2': 'line2',
            'city': 'city',
            'country': 'country',
            'postal_code': 'postalCode',
            'state': 'state',
            'email_address': 'emailAddress',
            'company_name': 'companyName',
            'first_name': 'firstName',
            'last_name': 'lastName'
        }

        self._address_key = None
        self._line1 = None
        self._line2 = None
        self._city = None
        self._country = None
        self._postal_code = None
        self._state = None
        self._email_address = None
        self._company_name = None
        self._first_name = None
        self._last_name = None

    @property
    def address_key(self):
        """
        Gets the address_key of this BillingAddress.
        Address identifier.


        :return: The address_key of this BillingAddress.
        :rtype: str
        """
        return self._address_key

    @address_key.setter
    def address_key(self, address_key):
        """
        Sets the address_key of this BillingAddress.
        Address identifier.


        :param address_key: The address_key of this BillingAddress.
        :type: str
        """
        self._address_key = address_key

    @property
    def line1(self):
        """
        Gets the line1 of this BillingAddress.
        Address line 1.


        :return: The line1 of this BillingAddress.
        :rtype: str
        """
        return self._line1

    @line1.setter
    def line1(self, line1):
        """
        Sets the line1 of this BillingAddress.
        Address line 1.


        :param line1: The line1 of this BillingAddress.
        :type: str
        """
        self._line1 = line1

    @property
    def line2(self):
        """
        Gets the line2 of this BillingAddress.
        Address line 2.


        :return: The line2 of this BillingAddress.
        :rtype: str
        """
        return self._line2

    @line2.setter
    def line2(self, line2):
        """
        Sets the line2 of this BillingAddress.
        Address line 2.


        :param line2: The line2 of this BillingAddress.
        :type: str
        """
        self._line2 = line2

    @property
    def city(self):
        """
        Gets the city of this BillingAddress.
        Name of the city.


        :return: The city of this BillingAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this BillingAddress.
        Name of the city.


        :param city: The city of this BillingAddress.
        :type: str
        """
        self._city = city

    @property
    def country(self):
        """
        Gets the country of this BillingAddress.
        Country of the address.


        :return: The country of this BillingAddress.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this BillingAddress.
        Country of the address.


        :param country: The country of this BillingAddress.
        :type: str
        """
        self._country = country

    @property
    def postal_code(self):
        """
        Gets the postal_code of this BillingAddress.
        Post code of the address.


        :return: The postal_code of this BillingAddress.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this BillingAddress.
        Post code of the address.


        :param postal_code: The postal_code of this BillingAddress.
        :type: str
        """
        self._postal_code = postal_code

    @property
    def state(self):
        """
        Gets the state of this BillingAddress.
        State of the address.


        :return: The state of this BillingAddress.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this BillingAddress.
        State of the address.


        :param state: The state of this BillingAddress.
        :type: str
        """
        self._state = state

    @property
    def email_address(self):
        """
        Gets the email_address of this BillingAddress.
        Contact person email address.


        :return: The email_address of this BillingAddress.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """
        Sets the email_address of this BillingAddress.
        Contact person email address.


        :param email_address: The email_address of this BillingAddress.
        :type: str
        """
        self._email_address = email_address

    @property
    def company_name(self):
        """
        Gets the company_name of this BillingAddress.
        Name of the customer company.


        :return: The company_name of this BillingAddress.
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """
        Sets the company_name of this BillingAddress.
        Name of the customer company.


        :param company_name: The company_name of this BillingAddress.
        :type: str
        """
        self._company_name = company_name

    @property
    def first_name(self):
        """
        Gets the first_name of this BillingAddress.
        First name of the contact person.


        :return: The first_name of this BillingAddress.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this BillingAddress.
        First name of the contact person.


        :param first_name: The first_name of this BillingAddress.
        :type: str
        """
        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this BillingAddress.
        Last name of the contact person.


        :return: The last_name of this BillingAddress.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this BillingAddress.
        Last name of the contact person.


        :param last_name: The last_name of this BillingAddress.
        :type: str
        """
        self._last_name = last_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDataAssetDetails(object):
    """
    Properties used in data asset update operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDataAssetDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_version:
            The value to assign to the model_version property of this UpdateDataAssetDetails.
        :type model_version: str

        :param model_type:
            The value to assign to the model_type property of this UpdateDataAssetDetails.
        :type model_type: str

        :param name:
            The value to assign to the name property of this UpdateDataAssetDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this UpdateDataAssetDetails.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this UpdateDataAssetDetails.
        :type object_status: int

        :param object_version:
            The value to assign to the object_version property of this UpdateDataAssetDetails.
        :type object_version: int

        :param identifier:
            The value to assign to the identifier property of this UpdateDataAssetDetails.
        :type identifier: str

        :param external_key:
            The value to assign to the external_key property of this UpdateDataAssetDetails.
        :type external_key: str

        :param asset_properties:
            The value to assign to the asset_properties property of this UpdateDataAssetDetails.
        :type asset_properties: dict(str, str)

        :param properties:
            The value to assign to the properties property of this UpdateDataAssetDetails.
        :type properties: dict(str, object)

        :param type:
            The value to assign to the type property of this UpdateDataAssetDetails.
        :type type: str

        :param native_type_system:
            The value to assign to the native_type_system property of this UpdateDataAssetDetails.
        :type native_type_system: oci.data_connectivity.models.TypeSystem

        :param registry_metadata:
            The value to assign to the registry_metadata property of this UpdateDataAssetDetails.
        :type registry_metadata: oci.data_connectivity.models.RegistryMetadata

        :param metadata:
            The value to assign to the metadata property of this UpdateDataAssetDetails.
        :type metadata: oci.data_connectivity.models.ObjectMetadata

        :param default_connection:
            The value to assign to the default_connection property of this UpdateDataAssetDetails.
        :type default_connection: oci.data_connectivity.models.Connection

        :param end_points:
            The value to assign to the end_points property of this UpdateDataAssetDetails.
        :type end_points: list[oci.data_connectivity.models.DpEndpoint]

        """
        self.swagger_types = {
            'model_version': 'str',
            'model_type': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'object_version': 'int',
            'identifier': 'str',
            'external_key': 'str',
            'asset_properties': 'dict(str, str)',
            'properties': 'dict(str, object)',
            'type': 'str',
            'native_type_system': 'TypeSystem',
            'registry_metadata': 'RegistryMetadata',
            'metadata': 'ObjectMetadata',
            'default_connection': 'Connection',
            'end_points': 'list[DpEndpoint]'
        }

        self.attribute_map = {
            'model_version': 'modelVersion',
            'model_type': 'modelType',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'object_version': 'objectVersion',
            'identifier': 'identifier',
            'external_key': 'externalKey',
            'asset_properties': 'assetProperties',
            'properties': 'properties',
            'type': 'type',
            'native_type_system': 'nativeTypeSystem',
            'registry_metadata': 'registryMetadata',
            'metadata': 'metadata',
            'default_connection': 'defaultConnection',
            'end_points': 'endPoints'
        }

        self._model_version = None
        self._model_type = None
        self._name = None
        self._description = None
        self._object_status = None
        self._object_version = None
        self._identifier = None
        self._external_key = None
        self._asset_properties = None
        self._properties = None
        self._type = None
        self._native_type_system = None
        self._registry_metadata = None
        self._metadata = None
        self._default_connection = None
        self._end_points = None

    @property
    def model_version(self):
        """
        Gets the model_version of this UpdateDataAssetDetails.
        The model version of an object.


        :return: The model_version of this UpdateDataAssetDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this UpdateDataAssetDetails.
        The model version of an object.


        :param model_version: The model_version of this UpdateDataAssetDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def model_type(self):
        """
        Gets the model_type of this UpdateDataAssetDetails.
        The type of the object.


        :return: The model_type of this UpdateDataAssetDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this UpdateDataAssetDetails.
        The type of the object.


        :param model_type: The model_type of this UpdateDataAssetDetails.
        :type: str
        """
        self._model_type = model_type

    @property
    def name(self):
        """
        Gets the name of this UpdateDataAssetDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this UpdateDataAssetDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateDataAssetDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this UpdateDataAssetDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this UpdateDataAssetDetails.
        User-defined description of the data asset.


        :return: The description of this UpdateDataAssetDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateDataAssetDetails.
        User-defined description of the data asset.


        :param description: The description of this UpdateDataAssetDetails.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this UpdateDataAssetDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this UpdateDataAssetDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this UpdateDataAssetDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this UpdateDataAssetDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def object_version(self):
        """
        Gets the object_version of this UpdateDataAssetDetails.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this UpdateDataAssetDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this UpdateDataAssetDetails.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this UpdateDataAssetDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def identifier(self):
        """
        Gets the identifier of this UpdateDataAssetDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this UpdateDataAssetDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this UpdateDataAssetDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this UpdateDataAssetDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def external_key(self):
        """
        Gets the external_key of this UpdateDataAssetDetails.
        The external key for the object.


        :return: The external_key of this UpdateDataAssetDetails.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this UpdateDataAssetDetails.
        The external key for the object.


        :param external_key: The external_key of this UpdateDataAssetDetails.
        :type: str
        """
        self._external_key = external_key

    @property
    def asset_properties(self):
        """
        Gets the asset_properties of this UpdateDataAssetDetails.
        Additional properties for the data asset.


        :return: The asset_properties of this UpdateDataAssetDetails.
        :rtype: dict(str, str)
        """
        return self._asset_properties

    @asset_properties.setter
    def asset_properties(self, asset_properties):
        """
        Sets the asset_properties of this UpdateDataAssetDetails.
        Additional properties for the data asset.


        :param asset_properties: The asset_properties of this UpdateDataAssetDetails.
        :type: dict(str, str)
        """
        self._asset_properties = asset_properties

    @property
    def properties(self):
        """
        **[Required]** Gets the properties of this UpdateDataAssetDetails.
        All the properties for the data asset in a key-value map format.


        :return: The properties of this UpdateDataAssetDetails.
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this UpdateDataAssetDetails.
        All the properties for the data asset in a key-value map format.


        :param properties: The properties of this UpdateDataAssetDetails.
        :type: dict(str, object)
        """
        self._properties = properties

    @property
    def type(self):
        """
        **[Required]** Gets the type of this UpdateDataAssetDetails.
        Specific DataAsset Type


        :return: The type of this UpdateDataAssetDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this UpdateDataAssetDetails.
        Specific DataAsset Type


        :param type: The type of this UpdateDataAssetDetails.
        :type: str
        """
        self._type = type

    @property
    def native_type_system(self):
        """
        Gets the native_type_system of this UpdateDataAssetDetails.

        :return: The native_type_system of this UpdateDataAssetDetails.
        :rtype: oci.data_connectivity.models.TypeSystem
        """
        return self._native_type_system

    @native_type_system.setter
    def native_type_system(self, native_type_system):
        """
        Sets the native_type_system of this UpdateDataAssetDetails.

        :param native_type_system: The native_type_system of this UpdateDataAssetDetails.
        :type: oci.data_connectivity.models.TypeSystem
        """
        self._native_type_system = native_type_system

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this UpdateDataAssetDetails.

        :return: The registry_metadata of this UpdateDataAssetDetails.
        :rtype: oci.data_connectivity.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this UpdateDataAssetDetails.

        :param registry_metadata: The registry_metadata of this UpdateDataAssetDetails.
        :type: oci.data_connectivity.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    @property
    def metadata(self):
        """
        Gets the metadata of this UpdateDataAssetDetails.

        :return: The metadata of this UpdateDataAssetDetails.
        :rtype: oci.data_connectivity.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this UpdateDataAssetDetails.

        :param metadata: The metadata of this UpdateDataAssetDetails.
        :type: oci.data_connectivity.models.ObjectMetadata
        """
        self._metadata = metadata

    @property
    def default_connection(self):
        """
        Gets the default_connection of this UpdateDataAssetDetails.

        :return: The default_connection of this UpdateDataAssetDetails.
        :rtype: oci.data_connectivity.models.Connection
        """
        return self._default_connection

    @default_connection.setter
    def default_connection(self, default_connection):
        """
        Sets the default_connection of this UpdateDataAssetDetails.

        :param default_connection: The default_connection of this UpdateDataAssetDetails.
        :type: oci.data_connectivity.models.Connection
        """
        self._default_connection = default_connection

    @property
    def end_points(self):
        """
        Gets the end_points of this UpdateDataAssetDetails.
        The list of endpoints with which this data asset is associated.


        :return: The end_points of this UpdateDataAssetDetails.
        :rtype: list[oci.data_connectivity.models.DpEndpoint]
        """
        return self._end_points

    @end_points.setter
    def end_points(self, end_points):
        """
        Sets the end_points of this UpdateDataAssetDetails.
        The list of endpoints with which this data asset is associated.


        :param end_points: The end_points of this UpdateDataAssetDetails.
        :type: list[oci.data_connectivity.models.DpEndpoint]
        """
        self._end_points = end_points

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .channel import Channel
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WebhookChannel(Channel):
    """
    The configuration for a Webhook channel.
    """

    #: A constant which can be used with the payload_version property of a WebhookChannel.
    #: This constant has a value of "1.0"
    PAYLOAD_VERSION_1_0 = "1.0"

    #: A constant which can be used with the payload_version property of a WebhookChannel.
    #: This constant has a value of "1.1"
    PAYLOAD_VERSION_1_1 = "1.1"

    def __init__(self, **kwargs):
        """
        Initializes a new WebhookChannel object with values from keyword arguments. The default value of the :py:attr:`~oci.oda.models.WebhookChannel.type` attribute
        of this class is ``WEBHOOK`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this WebhookChannel.
        :type id: str

        :param name:
            The value to assign to the name property of this WebhookChannel.
        :type name: str

        :param description:
            The value to assign to the description property of this WebhookChannel.
        :type description: str

        :param category:
            The value to assign to the category property of this WebhookChannel.
            Allowed values for this property are: "AGENT", "APPLICATION", "BOT", "BOT_AS_AGENT", "SYSTEM", "EVENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type category: str

        :param type:
            The value to assign to the type property of this WebhookChannel.
            Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param session_expiry_duration_in_milliseconds:
            The value to assign to the session_expiry_duration_in_milliseconds property of this WebhookChannel.
        :type session_expiry_duration_in_milliseconds: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this WebhookChannel.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this WebhookChannel.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this WebhookChannel.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this WebhookChannel.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this WebhookChannel.
        :type defined_tags: dict(str, dict(str, object))

        :param outbound_url:
            The value to assign to the outbound_url property of this WebhookChannel.
        :type outbound_url: str

        :param payload_version:
            The value to assign to the payload_version property of this WebhookChannel.
            Allowed values for this property are: "1.0", "1.1", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type payload_version: str

        :param bot_id:
            The value to assign to the bot_id property of this WebhookChannel.
        :type bot_id: str

        :param webhook_url:
            The value to assign to the webhook_url property of this WebhookChannel.
        :type webhook_url: str

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'category': 'str',
            'type': 'str',
            'session_expiry_duration_in_milliseconds': 'int',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'outbound_url': 'str',
            'payload_version': 'str',
            'bot_id': 'str',
            'webhook_url': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'category': 'category',
            'type': 'type',
            'session_expiry_duration_in_milliseconds': 'sessionExpiryDurationInMilliseconds',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'outbound_url': 'outboundUrl',
            'payload_version': 'payloadVersion',
            'bot_id': 'botId',
            'webhook_url': 'webhookUrl'
        }

        self._id = None
        self._name = None
        self._description = None
        self._category = None
        self._type = None
        self._session_expiry_duration_in_milliseconds = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None
        self._outbound_url = None
        self._payload_version = None
        self._bot_id = None
        self._webhook_url = None
        self._type = 'WEBHOOK'

    @property
    def outbound_url(self):
        """
        **[Required]** Gets the outbound_url of this WebhookChannel.
        The URL to send responses to.


        :return: The outbound_url of this WebhookChannel.
        :rtype: str
        """
        return self._outbound_url

    @outbound_url.setter
    def outbound_url(self, outbound_url):
        """
        Sets the outbound_url of this WebhookChannel.
        The URL to send responses to.


        :param outbound_url: The outbound_url of this WebhookChannel.
        :type: str
        """
        self._outbound_url = outbound_url

    @property
    def payload_version(self):
        """
        **[Required]** Gets the payload_version of this WebhookChannel.
        The version for payloads.

        Allowed values for this property are: "1.0", "1.1", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The payload_version of this WebhookChannel.
        :rtype: str
        """
        return self._payload_version

    @payload_version.setter
    def payload_version(self, payload_version):
        """
        Sets the payload_version of this WebhookChannel.
        The version for payloads.


        :param payload_version: The payload_version of this WebhookChannel.
        :type: str
        """
        allowed_values = ["1.0", "1.1"]
        if not value_allowed_none_or_none_sentinel(payload_version, allowed_values):
            payload_version = 'UNKNOWN_ENUM_VALUE'
        self._payload_version = payload_version

    @property
    def bot_id(self):
        """
        Gets the bot_id of this WebhookChannel.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :return: The bot_id of this WebhookChannel.
        :rtype: str
        """
        return self._bot_id

    @bot_id.setter
    def bot_id(self, bot_id):
        """
        Sets the bot_id of this WebhookChannel.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :param bot_id: The bot_id of this WebhookChannel.
        :type: str
        """
        self._bot_id = bot_id

    @property
    def webhook_url(self):
        """
        **[Required]** Gets the webhook_url of this WebhookChannel.
        The URL to use to send messages to this channel.
        This will be generally be used to configure a webhook in a 3rd party messaging system to send messages to this channel.


        :return: The webhook_url of this WebhookChannel.
        :rtype: str
        """
        return self._webhook_url

    @webhook_url.setter
    def webhook_url(self, webhook_url):
        """
        Sets the webhook_url of this WebhookChannel.
        The URL to use to send messages to this channel.
        This will be generally be used to configure a webhook in a 3rd party messaging system to send messages to this channel.


        :param webhook_url: The webhook_url of this WebhookChannel.
        :type: str
        """
        self._webhook_url = webhook_url

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RevocationStatus(object):
    """
    The current revocation status of the certificate or certificate authority (CA).
    """

    #: A constant which can be used with the revocation_reason property of a RevocationStatus.
    #: This constant has a value of "UNSPECIFIED"
    REVOCATION_REASON_UNSPECIFIED = "UNSPECIFIED"

    #: A constant which can be used with the revocation_reason property of a RevocationStatus.
    #: This constant has a value of "KEY_COMPROMISE"
    REVOCATION_REASON_KEY_COMPROMISE = "KEY_COMPROMISE"

    #: A constant which can be used with the revocation_reason property of a RevocationStatus.
    #: This constant has a value of "CA_COMPROMISE"
    REVOCATION_REASON_CA_COMPROMISE = "CA_COMPROMISE"

    #: A constant which can be used with the revocation_reason property of a RevocationStatus.
    #: This constant has a value of "AFFILIATION_CHANGED"
    REVOCATION_REASON_AFFILIATION_CHANGED = "AFFILIATION_CHANGED"

    #: A constant which can be used with the revocation_reason property of a RevocationStatus.
    #: This constant has a value of "SUPERSEDED"
    REVOCATION_REASON_SUPERSEDED = "SUPERSEDED"

    #: A constant which can be used with the revocation_reason property of a RevocationStatus.
    #: This constant has a value of "CESSATION_OF_OPERATION"
    REVOCATION_REASON_CESSATION_OF_OPERATION = "CESSATION_OF_OPERATION"

    #: A constant which can be used with the revocation_reason property of a RevocationStatus.
    #: This constant has a value of "PRIVILEGE_WITHDRAWN"
    REVOCATION_REASON_PRIVILEGE_WITHDRAWN = "PRIVILEGE_WITHDRAWN"

    #: A constant which can be used with the revocation_reason property of a RevocationStatus.
    #: This constant has a value of "AA_COMPROMISE"
    REVOCATION_REASON_AA_COMPROMISE = "AA_COMPROMISE"

    def __init__(self, **kwargs):
        """
        Initializes a new RevocationStatus object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_revoked:
            The value to assign to the time_revoked property of this RevocationStatus.
        :type time_revoked: datetime

        :param revocation_reason:
            The value to assign to the revocation_reason property of this RevocationStatus.
            Allowed values for this property are: "UNSPECIFIED", "KEY_COMPROMISE", "CA_COMPROMISE", "AFFILIATION_CHANGED", "SUPERSEDED", "CESSATION_OF_OPERATION", "PRIVILEGE_WITHDRAWN", "AA_COMPROMISE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type revocation_reason: str

        """
        self.swagger_types = {
            'time_revoked': 'datetime',
            'revocation_reason': 'str'
        }

        self.attribute_map = {
            'time_revoked': 'timeRevoked',
            'revocation_reason': 'revocationReason'
        }

        self._time_revoked = None
        self._revocation_reason = None

    @property
    def time_revoked(self):
        """
        **[Required]** Gets the time_revoked of this RevocationStatus.
        The time when the certificate or CA was revoked.


        :return: The time_revoked of this RevocationStatus.
        :rtype: datetime
        """
        return self._time_revoked

    @time_revoked.setter
    def time_revoked(self, time_revoked):
        """
        Sets the time_revoked of this RevocationStatus.
        The time when the certificate or CA was revoked.


        :param time_revoked: The time_revoked of this RevocationStatus.
        :type: datetime
        """
        self._time_revoked = time_revoked

    @property
    def revocation_reason(self):
        """
        **[Required]** Gets the revocation_reason of this RevocationStatus.
        The reason that the certificate or CA was revoked.

        Allowed values for this property are: "UNSPECIFIED", "KEY_COMPROMISE", "CA_COMPROMISE", "AFFILIATION_CHANGED", "SUPERSEDED", "CESSATION_OF_OPERATION", "PRIVILEGE_WITHDRAWN", "AA_COMPROMISE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The revocation_reason of this RevocationStatus.
        :rtype: str
        """
        return self._revocation_reason

    @revocation_reason.setter
    def revocation_reason(self, revocation_reason):
        """
        Sets the revocation_reason of this RevocationStatus.
        The reason that the certificate or CA was revoked.


        :param revocation_reason: The revocation_reason of this RevocationStatus.
        :type: str
        """
        allowed_values = ["UNSPECIFIED", "KEY_COMPROMISE", "CA_COMPROMISE", "AFFILIATION_CHANGED", "SUPERSEDED", "CESSATION_OF_OPERATION", "PRIVILEGE_WITHDRAWN", "AA_COMPROMISE"]
        if not value_allowed_none_or_none_sentinel(revocation_reason, allowed_values):
            revocation_reason = 'UNKNOWN_ENUM_VALUE'
        self._revocation_reason = revocation_reason

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GlobalSettings(object):
    """
    Details of the tenancy level global settings in Data Safe.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GlobalSettings object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_paid_usage:
            The value to assign to the is_paid_usage property of this GlobalSettings.
        :type is_paid_usage: bool

        :param online_retention_period:
            The value to assign to the online_retention_period property of this GlobalSettings.
        :type online_retention_period: int

        :param offline_retention_period:
            The value to assign to the offline_retention_period property of this GlobalSettings.
        :type offline_retention_period: int

        """
        self.swagger_types = {
            'is_paid_usage': 'bool',
            'online_retention_period': 'int',
            'offline_retention_period': 'int'
        }

        self.attribute_map = {
            'is_paid_usage': 'isPaidUsage',
            'online_retention_period': 'onlineRetentionPeriod',
            'offline_retention_period': 'offlineRetentionPeriod'
        }

        self._is_paid_usage = None
        self._online_retention_period = None
        self._offline_retention_period = None

    @property
    def is_paid_usage(self):
        """
        Gets the is_paid_usage of this GlobalSettings.
        The paid usage option chosen by the customer admin.


        :return: The is_paid_usage of this GlobalSettings.
        :rtype: bool
        """
        return self._is_paid_usage

    @is_paid_usage.setter
    def is_paid_usage(self, is_paid_usage):
        """
        Sets the is_paid_usage of this GlobalSettings.
        The paid usage option chosen by the customer admin.


        :param is_paid_usage: The is_paid_usage of this GlobalSettings.
        :type: bool
        """
        self._is_paid_usage = is_paid_usage

    @property
    def online_retention_period(self):
        """
        Gets the online_retention_period of this GlobalSettings.
        The online retention period in months.


        :return: The online_retention_period of this GlobalSettings.
        :rtype: int
        """
        return self._online_retention_period

    @online_retention_period.setter
    def online_retention_period(self, online_retention_period):
        """
        Sets the online_retention_period of this GlobalSettings.
        The online retention period in months.


        :param online_retention_period: The online_retention_period of this GlobalSettings.
        :type: int
        """
        self._online_retention_period = online_retention_period

    @property
    def offline_retention_period(self):
        """
        Gets the offline_retention_period of this GlobalSettings.
        The offline retention period in months.


        :return: The offline_retention_period of this GlobalSettings.
        :rtype: int
        """
        return self._offline_retention_period

    @offline_retention_period.setter
    def offline_retention_period(self, offline_retention_period):
        """
        Sets the offline_retention_period of this GlobalSettings.
        The offline retention period in months.


        :param offline_retention_period: The offline_retention_period of this GlobalSettings.
        :type: int
        """
        self._offline_retention_period = offline_retention_period

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SpanSnapshot(object):
    """
    Definition of a span snapshot object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SpanSnapshot object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this SpanSnapshot.
        :type key: str

        :param span_name:
            The value to assign to the span_name property of this SpanSnapshot.
        :type span_name: str

        :param time_started:
            The value to assign to the time_started property of this SpanSnapshot.
        :type time_started: datetime

        :param time_ended:
            The value to assign to the time_ended property of this SpanSnapshot.
        :type time_ended: datetime

        :param span_snapshot_details:
            The value to assign to the span_snapshot_details property of this SpanSnapshot.
        :type span_snapshot_details: list[oci.apm_traces.models.SnapshotDetail]

        :param thread_snapshots:
            The value to assign to the thread_snapshots property of this SpanSnapshot.
        :type thread_snapshots: list[oci.apm_traces.models.ThreadSnapshot]

        :param children:
            The value to assign to the children property of this SpanSnapshot.
        :type children: list[oci.apm_traces.models.SpanSnapshot]

        """
        self.swagger_types = {
            'key': 'str',
            'span_name': 'str',
            'time_started': 'datetime',
            'time_ended': 'datetime',
            'span_snapshot_details': 'list[SnapshotDetail]',
            'thread_snapshots': 'list[ThreadSnapshot]',
            'children': 'list[SpanSnapshot]'
        }

        self.attribute_map = {
            'key': 'key',
            'span_name': 'spanName',
            'time_started': 'timeStarted',
            'time_ended': 'timeEnded',
            'span_snapshot_details': 'spanSnapshotDetails',
            'thread_snapshots': 'threadSnapshots',
            'children': 'children'
        }

        self._key = None
        self._span_name = None
        self._time_started = None
        self._time_ended = None
        self._span_snapshot_details = None
        self._thread_snapshots = None
        self._children = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this SpanSnapshot.
        Unique identifier (spanId) for the trace span.


        :return: The key of this SpanSnapshot.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this SpanSnapshot.
        Unique identifier (spanId) for the trace span.


        :param key: The key of this SpanSnapshot.
        :type: str
        """
        self._key = key

    @property
    def span_name(self):
        """
        Gets the span_name of this SpanSnapshot.
        Span name associated with the trace.


        :return: The span_name of this SpanSnapshot.
        :rtype: str
        """
        return self._span_name

    @span_name.setter
    def span_name(self, span_name):
        """
        Sets the span_name of this SpanSnapshot.
        Span name associated with the trace.


        :param span_name: The span_name of this SpanSnapshot.
        :type: str
        """
        self._span_name = span_name

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this SpanSnapshot.
        Start time of the span.


        :return: The time_started of this SpanSnapshot.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this SpanSnapshot.
        Start time of the span.


        :param time_started: The time_started of this SpanSnapshot.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_ended(self):
        """
        **[Required]** Gets the time_ended of this SpanSnapshot.
        End time of the span.


        :return: The time_ended of this SpanSnapshot.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this SpanSnapshot.
        End time of the span.


        :param time_ended: The time_ended of this SpanSnapshot.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def span_snapshot_details(self):
        """
        Gets the span_snapshot_details of this SpanSnapshot.
        Span snapshots properties.


        :return: The span_snapshot_details of this SpanSnapshot.
        :rtype: list[oci.apm_traces.models.SnapshotDetail]
        """
        return self._span_snapshot_details

    @span_snapshot_details.setter
    def span_snapshot_details(self, span_snapshot_details):
        """
        Sets the span_snapshot_details of this SpanSnapshot.
        Span snapshots properties.


        :param span_snapshot_details: The span_snapshot_details of this SpanSnapshot.
        :type: list[oci.apm_traces.models.SnapshotDetail]
        """
        self._span_snapshot_details = span_snapshot_details

    @property
    def thread_snapshots(self):
        """
        Gets the thread_snapshots of this SpanSnapshot.
        Thread snapshots.


        :return: The thread_snapshots of this SpanSnapshot.
        :rtype: list[oci.apm_traces.models.ThreadSnapshot]
        """
        return self._thread_snapshots

    @thread_snapshots.setter
    def thread_snapshots(self, thread_snapshots):
        """
        Sets the thread_snapshots of this SpanSnapshot.
        Thread snapshots.


        :param thread_snapshots: The thread_snapshots of this SpanSnapshot.
        :type: list[oci.apm_traces.models.ThreadSnapshot]
        """
        self._thread_snapshots = thread_snapshots

    @property
    def children(self):
        """
        Gets the children of this SpanSnapshot.
        An array of child span snapshots.


        :return: The children of this SpanSnapshot.
        :rtype: list[oci.apm_traces.models.SpanSnapshot]
        """
        return self._children

    @children.setter
    def children(self, children):
        """
        Sets the children of this SpanSnapshot.
        An array of child span snapshots.


        :param children: The children of this SpanSnapshot.
        :type: list[oci.apm_traces.models.SpanSnapshot]
        """
        self._children = children

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .filter import Filter
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BitbucketCloudFilter(Filter):
    """
    The filter for Bitbucket Cloud events.
    """

    #: A constant which can be used with the events property of a BitbucketCloudFilter.
    #: This constant has a value of "PUSH"
    EVENTS_PUSH = "PUSH"

    #: A constant which can be used with the events property of a BitbucketCloudFilter.
    #: This constant has a value of "PULL_REQUEST_CREATED"
    EVENTS_PULL_REQUEST_CREATED = "PULL_REQUEST_CREATED"

    #: A constant which can be used with the events property of a BitbucketCloudFilter.
    #: This constant has a value of "PULL_REQUEST_UPDATED"
    EVENTS_PULL_REQUEST_UPDATED = "PULL_REQUEST_UPDATED"

    #: A constant which can be used with the events property of a BitbucketCloudFilter.
    #: This constant has a value of "PULL_REQUEST_MERGED"
    EVENTS_PULL_REQUEST_MERGED = "PULL_REQUEST_MERGED"

    def __init__(self, **kwargs):
        """
        Initializes a new BitbucketCloudFilter object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.BitbucketCloudFilter.trigger_source` attribute
        of this class is ``BITBUCKET_CLOUD`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param trigger_source:
            The value to assign to the trigger_source property of this BitbucketCloudFilter.
        :type trigger_source: str

        :param events:
            The value to assign to the events property of this BitbucketCloudFilter.
            Allowed values for items in this list are: "PUSH", "PULL_REQUEST_CREATED", "PULL_REQUEST_UPDATED", "PULL_REQUEST_MERGED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type events: list[str]

        :param include:
            The value to assign to the include property of this BitbucketCloudFilter.
        :type include: oci.devops.models.BitbucketCloudFilterAttributes

        """
        self.swagger_types = {
            'trigger_source': 'str',
            'events': 'list[str]',
            'include': 'BitbucketCloudFilterAttributes'
        }

        self.attribute_map = {
            'trigger_source': 'triggerSource',
            'events': 'events',
            'include': 'include'
        }

        self._trigger_source = None
        self._events = None
        self._include = None
        self._trigger_source = 'BITBUCKET_CLOUD'

    @property
    def events(self):
        """
        Gets the events of this BitbucketCloudFilter.
        The events, for example, PUSH, PULL_REQUEST_MERGE.

        Allowed values for items in this list are: "PUSH", "PULL_REQUEST_CREATED", "PULL_REQUEST_UPDATED", "PULL_REQUEST_MERGED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The events of this BitbucketCloudFilter.
        :rtype: list[str]
        """
        return self._events

    @events.setter
    def events(self, events):
        """
        Sets the events of this BitbucketCloudFilter.
        The events, for example, PUSH, PULL_REQUEST_MERGE.


        :param events: The events of this BitbucketCloudFilter.
        :type: list[str]
        """
        allowed_values = ["PUSH", "PULL_REQUEST_CREATED", "PULL_REQUEST_UPDATED", "PULL_REQUEST_MERGED"]
        if events:
            events[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in events]
        self._events = events

    @property
    def include(self):
        """
        Gets the include of this BitbucketCloudFilter.

        :return: The include of this BitbucketCloudFilter.
        :rtype: oci.devops.models.BitbucketCloudFilterAttributes
        """
        return self._include

    @include.setter
    def include(self, include):
        """
        Sets the include of this BitbucketCloudFilter.

        :param include: The include of this BitbucketCloudFilter.
        :type: oci.devops.models.BitbucketCloudFilterAttributes
        """
        self._include = include

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .instance_power_action_details import InstancePowerActionDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SoftResetActionDetails(InstancePowerActionDetails):
    """
    Parameters for the softReset `instance action`__. If omitted, default values are used.

    __ https://docs.cloud.oracle.com/iaas/latest/Instance/InstanceAction
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SoftResetActionDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.SoftResetActionDetails.action_type` attribute
        of this class is ``softreset`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param action_type:
            The value to assign to the action_type property of this SoftResetActionDetails.
        :type action_type: str

        :param allow_dense_reboot_migration:
            The value to assign to the allow_dense_reboot_migration property of this SoftResetActionDetails.
        :type allow_dense_reboot_migration: bool

        """
        self.swagger_types = {
            'action_type': 'str',
            'allow_dense_reboot_migration': 'bool'
        }

        self.attribute_map = {
            'action_type': 'actionType',
            'allow_dense_reboot_migration': 'allowDenseRebootMigration'
        }

        self._action_type = None
        self._allow_dense_reboot_migration = None
        self._action_type = 'softreset'

    @property
    def allow_dense_reboot_migration(self):
        """
        Gets the allow_dense_reboot_migration of this SoftResetActionDetails.
        For instances with a date in the Maintenance reboot field, the flag denoting whether reboot migration is enabled for instances that use the DenseIO shape. The default value is 'false'.


        :return: The allow_dense_reboot_migration of this SoftResetActionDetails.
        :rtype: bool
        """
        return self._allow_dense_reboot_migration

    @allow_dense_reboot_migration.setter
    def allow_dense_reboot_migration(self, allow_dense_reboot_migration):
        """
        Sets the allow_dense_reboot_migration of this SoftResetActionDetails.
        For instances with a date in the Maintenance reboot field, the flag denoting whether reboot migration is enabled for instances that use the DenseIO shape. The default value is 'false'.


        :param allow_dense_reboot_migration: The allow_dense_reboot_migration of this SoftResetActionDetails.
        :type: bool
        """
        self._allow_dense_reboot_migration = allow_dense_reboot_migration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UploadFileStatus(object):
    """
    Upload File Status
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UploadFileStatus object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param file_name:
            The value to assign to the file_name property of this UploadFileStatus.
        :type file_name: str

        :param is_valid:
            The value to assign to the is_valid property of this UploadFileStatus.
        :type is_valid: bool

        """
        self.swagger_types = {
            'file_name': 'str',
            'is_valid': 'bool'
        }

        self.attribute_map = {
            'file_name': 'fileName',
            'is_valid': 'isValid'
        }

        self._file_name = None
        self._is_valid = None

    @property
    def file_name(self):
        """
        Gets the file_name of this UploadFileStatus.
        Name of the file.


        :return: The file_name of this UploadFileStatus.
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """
        Sets the file_name of this UploadFileStatus.
        Name of the file.


        :param file_name: The file_name of this UploadFileStatus.
        :type: str
        """
        self._file_name = file_name

    @property
    def is_valid(self):
        """
        Gets the is_valid of this UploadFileStatus.
        Is Valid flag.


        :return: The is_valid of this UploadFileStatus.
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """
        Sets the is_valid of this UploadFileStatus.
        Is Valid flag.


        :param is_valid: The is_valid of this UploadFileStatus.
        :type: bool
        """
        self._is_valid = is_valid

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlTuningAdvisorTaskRecommendationSummary(object):
    """
    A recommendation for a given object in a SQL Tuning Task.
    """

    #: A constant which can be used with the recommendation_type property of a SqlTuningAdvisorTaskRecommendationSummary.
    #: This constant has a value of "STATISTICS"
    RECOMMENDATION_TYPE_STATISTICS = "STATISTICS"

    #: A constant which can be used with the recommendation_type property of a SqlTuningAdvisorTaskRecommendationSummary.
    #: This constant has a value of "INDEX"
    RECOMMENDATION_TYPE_INDEX = "INDEX"

    #: A constant which can be used with the recommendation_type property of a SqlTuningAdvisorTaskRecommendationSummary.
    #: This constant has a value of "SQL_PROFILE"
    RECOMMENDATION_TYPE_SQL_PROFILE = "SQL_PROFILE"

    #: A constant which can be used with the recommendation_type property of a SqlTuningAdvisorTaskRecommendationSummary.
    #: This constant has a value of "RESTRUCTURE_SQL"
    RECOMMENDATION_TYPE_RESTRUCTURE_SQL = "RESTRUCTURE_SQL"

    #: A constant which can be used with the recommendation_type property of a SqlTuningAdvisorTaskRecommendationSummary.
    #: This constant has a value of "ALTERNATIVE_PLANS"
    RECOMMENDATION_TYPE_ALTERNATIVE_PLANS = "ALTERNATIVE_PLANS"

    #: A constant which can be used with the recommendation_type property of a SqlTuningAdvisorTaskRecommendationSummary.
    #: This constant has a value of "ERROR"
    RECOMMENDATION_TYPE_ERROR = "ERROR"

    #: A constant which can be used with the recommendation_type property of a SqlTuningAdvisorTaskRecommendationSummary.
    #: This constant has a value of "MISCELLANEOUS"
    RECOMMENDATION_TYPE_MISCELLANEOUS = "MISCELLANEOUS"

    def __init__(self, **kwargs):
        """
        Initializes a new SqlTuningAdvisorTaskRecommendationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sql_tuning_advisor_task_id:
            The value to assign to the sql_tuning_advisor_task_id property of this SqlTuningAdvisorTaskRecommendationSummary.
        :type sql_tuning_advisor_task_id: int

        :param sql_tuning_advisor_task_object_id:
            The value to assign to the sql_tuning_advisor_task_object_id property of this SqlTuningAdvisorTaskRecommendationSummary.
        :type sql_tuning_advisor_task_object_id: int

        :param recommendation_key:
            The value to assign to the recommendation_key property of this SqlTuningAdvisorTaskRecommendationSummary.
        :type recommendation_key: int

        :param recommendation_type:
            The value to assign to the recommendation_type property of this SqlTuningAdvisorTaskRecommendationSummary.
            Allowed values for this property are: "STATISTICS", "INDEX", "SQL_PROFILE", "RESTRUCTURE_SQL", "ALTERNATIVE_PLANS", "ERROR", "MISCELLANEOUS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type recommendation_type: str

        :param finding:
            The value to assign to the finding property of this SqlTuningAdvisorTaskRecommendationSummary.
        :type finding: str

        :param recommendation:
            The value to assign to the recommendation property of this SqlTuningAdvisorTaskRecommendationSummary.
        :type recommendation: str

        :param rationale:
            The value to assign to the rationale property of this SqlTuningAdvisorTaskRecommendationSummary.
        :type rationale: str

        :param benefit:
            The value to assign to the benefit property of this SqlTuningAdvisorTaskRecommendationSummary.
        :type benefit: float

        :param implement_action_sql:
            The value to assign to the implement_action_sql property of this SqlTuningAdvisorTaskRecommendationSummary.
        :type implement_action_sql: str

        :param is_parallel_execution:
            The value to assign to the is_parallel_execution property of this SqlTuningAdvisorTaskRecommendationSummary.
        :type is_parallel_execution: bool

        """
        self.swagger_types = {
            'sql_tuning_advisor_task_id': 'int',
            'sql_tuning_advisor_task_object_id': 'int',
            'recommendation_key': 'int',
            'recommendation_type': 'str',
            'finding': 'str',
            'recommendation': 'str',
            'rationale': 'str',
            'benefit': 'float',
            'implement_action_sql': 'str',
            'is_parallel_execution': 'bool'
        }

        self.attribute_map = {
            'sql_tuning_advisor_task_id': 'sqlTuningAdvisorTaskId',
            'sql_tuning_advisor_task_object_id': 'sqlTuningAdvisorTaskObjectId',
            'recommendation_key': 'recommendationKey',
            'recommendation_type': 'recommendationType',
            'finding': 'finding',
            'recommendation': 'recommendation',
            'rationale': 'rationale',
            'benefit': 'benefit',
            'implement_action_sql': 'implementActionSql',
            'is_parallel_execution': 'isParallelExecution'
        }

        self._sql_tuning_advisor_task_id = None
        self._sql_tuning_advisor_task_object_id = None
        self._recommendation_key = None
        self._recommendation_type = None
        self._finding = None
        self._recommendation = None
        self._rationale = None
        self._benefit = None
        self._implement_action_sql = None
        self._is_parallel_execution = None

    @property
    def sql_tuning_advisor_task_id(self):
        """
        **[Required]** Gets the sql_tuning_advisor_task_id of this SqlTuningAdvisorTaskRecommendationSummary.
        The unique identifier of the task. This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The sql_tuning_advisor_task_id of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: int
        """
        return self._sql_tuning_advisor_task_id

    @sql_tuning_advisor_task_id.setter
    def sql_tuning_advisor_task_id(self, sql_tuning_advisor_task_id):
        """
        Sets the sql_tuning_advisor_task_id of this SqlTuningAdvisorTaskRecommendationSummary.
        The unique identifier of the task. This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param sql_tuning_advisor_task_id: The sql_tuning_advisor_task_id of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: int
        """
        self._sql_tuning_advisor_task_id = sql_tuning_advisor_task_id

    @property
    def sql_tuning_advisor_task_object_id(self):
        """
        **[Required]** Gets the sql_tuning_advisor_task_object_id of this SqlTuningAdvisorTaskRecommendationSummary.
        The key of the object to which these recommendations apply. This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The sql_tuning_advisor_task_object_id of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: int
        """
        return self._sql_tuning_advisor_task_object_id

    @sql_tuning_advisor_task_object_id.setter
    def sql_tuning_advisor_task_object_id(self, sql_tuning_advisor_task_object_id):
        """
        Sets the sql_tuning_advisor_task_object_id of this SqlTuningAdvisorTaskRecommendationSummary.
        The key of the object to which these recommendations apply. This is not the `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param sql_tuning_advisor_task_object_id: The sql_tuning_advisor_task_object_id of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: int
        """
        self._sql_tuning_advisor_task_object_id = sql_tuning_advisor_task_object_id

    @property
    def recommendation_key(self):
        """
        **[Required]** Gets the recommendation_key of this SqlTuningAdvisorTaskRecommendationSummary.
        The unique identifier of the recommendation in the scope of the task.


        :return: The recommendation_key of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: int
        """
        return self._recommendation_key

    @recommendation_key.setter
    def recommendation_key(self, recommendation_key):
        """
        Sets the recommendation_key of this SqlTuningAdvisorTaskRecommendationSummary.
        The unique identifier of the recommendation in the scope of the task.


        :param recommendation_key: The recommendation_key of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: int
        """
        self._recommendation_key = recommendation_key

    @property
    def recommendation_type(self):
        """
        **[Required]** Gets the recommendation_type of this SqlTuningAdvisorTaskRecommendationSummary.
        Type of recommendation.

        Allowed values for this property are: "STATISTICS", "INDEX", "SQL_PROFILE", "RESTRUCTURE_SQL", "ALTERNATIVE_PLANS", "ERROR", "MISCELLANEOUS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The recommendation_type of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: str
        """
        return self._recommendation_type

    @recommendation_type.setter
    def recommendation_type(self, recommendation_type):
        """
        Sets the recommendation_type of this SqlTuningAdvisorTaskRecommendationSummary.
        Type of recommendation.


        :param recommendation_type: The recommendation_type of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: str
        """
        allowed_values = ["STATISTICS", "INDEX", "SQL_PROFILE", "RESTRUCTURE_SQL", "ALTERNATIVE_PLANS", "ERROR", "MISCELLANEOUS"]
        if not value_allowed_none_or_none_sentinel(recommendation_type, allowed_values):
            recommendation_type = 'UNKNOWN_ENUM_VALUE'
        self._recommendation_type = recommendation_type

    @property
    def finding(self):
        """
        Gets the finding of this SqlTuningAdvisorTaskRecommendationSummary.
        Summary of the issue found in the SQL statement.


        :return: The finding of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: str
        """
        return self._finding

    @finding.setter
    def finding(self, finding):
        """
        Sets the finding of this SqlTuningAdvisorTaskRecommendationSummary.
        Summary of the issue found in the SQL statement.


        :param finding: The finding of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: str
        """
        self._finding = finding

    @property
    def recommendation(self):
        """
        Gets the recommendation of this SqlTuningAdvisorTaskRecommendationSummary.
        The recommendation for a specific finding.


        :return: The recommendation of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: str
        """
        return self._recommendation

    @recommendation.setter
    def recommendation(self, recommendation):
        """
        Sets the recommendation of this SqlTuningAdvisorTaskRecommendationSummary.
        The recommendation for a specific finding.


        :param recommendation: The recommendation of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: str
        """
        self._recommendation = recommendation

    @property
    def rationale(self):
        """
        Gets the rationale of this SqlTuningAdvisorTaskRecommendationSummary.
        Describes the reasoning behind the recommendation and how it relates to the finding.


        :return: The rationale of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: str
        """
        return self._rationale

    @rationale.setter
    def rationale(self, rationale):
        """
        Sets the rationale of this SqlTuningAdvisorTaskRecommendationSummary.
        Describes the reasoning behind the recommendation and how it relates to the finding.


        :param rationale: The rationale of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: str
        """
        self._rationale = rationale

    @property
    def benefit(self):
        """
        Gets the benefit of this SqlTuningAdvisorTaskRecommendationSummary.
        The percentage benefit of this implementation.


        :return: The benefit of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: float
        """
        return self._benefit

    @benefit.setter
    def benefit(self, benefit):
        """
        Sets the benefit of this SqlTuningAdvisorTaskRecommendationSummary.
        The percentage benefit of this implementation.


        :param benefit: The benefit of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: float
        """
        self._benefit = benefit

    @property
    def implement_action_sql(self):
        """
        Gets the implement_action_sql of this SqlTuningAdvisorTaskRecommendationSummary.
        Action sql to be implemented based on the recommendation result.


        :return: The implement_action_sql of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: str
        """
        return self._implement_action_sql

    @implement_action_sql.setter
    def implement_action_sql(self, implement_action_sql):
        """
        Sets the implement_action_sql of this SqlTuningAdvisorTaskRecommendationSummary.
        Action sql to be implemented based on the recommendation result.


        :param implement_action_sql: The implement_action_sql of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: str
        """
        self._implement_action_sql = implement_action_sql

    @property
    def is_parallel_execution(self):
        """
        Gets the is_parallel_execution of this SqlTuningAdvisorTaskRecommendationSummary.
        Indicates whether a SQL Profile recommendation uses parallel execution.


        :return: The is_parallel_execution of this SqlTuningAdvisorTaskRecommendationSummary.
        :rtype: bool
        """
        return self._is_parallel_execution

    @is_parallel_execution.setter
    def is_parallel_execution(self, is_parallel_execution):
        """
        Sets the is_parallel_execution of this SqlTuningAdvisorTaskRecommendationSummary.
        Indicates whether a SQL Profile recommendation uses parallel execution.


        :param is_parallel_execution: The is_parallel_execution of this SqlTuningAdvisorTaskRecommendationSummary.
        :type: bool
        """
        self._is_parallel_execution = is_parallel_execution

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MonitoredResourceAliasCredential(object):
    """
    Monitored Resource Alias Credential Details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MonitoredResourceAliasCredential object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this MonitoredResourceAliasCredential.
        :type source: str

        :param name:
            The value to assign to the name property of this MonitoredResourceAliasCredential.
        :type name: str

        :param credential:
            The value to assign to the credential property of this MonitoredResourceAliasCredential.
        :type credential: oci.stack_monitoring.models.MonitoredResourceAliasSourceCredential

        """
        self.swagger_types = {
            'source': 'str',
            'name': 'str',
            'credential': 'MonitoredResourceAliasSourceCredential'
        }

        self.attribute_map = {
            'source': 'source',
            'name': 'name',
            'credential': 'credential'
        }

        self._source = None
        self._name = None
        self._credential = None

    @property
    def source(self):
        """
        **[Required]** Gets the source of this MonitoredResourceAliasCredential.
        The source type and source name combination,delimited with (.) separator. Ex. {source type}.{source name} and source type max char limit is 63.


        :return: The source of this MonitoredResourceAliasCredential.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this MonitoredResourceAliasCredential.
        The source type and source name combination,delimited with (.) separator. Ex. {source type}.{source name} and source type max char limit is 63.


        :param source: The source of this MonitoredResourceAliasCredential.
        :type: str
        """
        self._source = source

    @property
    def name(self):
        """
        **[Required]** Gets the name of this MonitoredResourceAliasCredential.
        The name of the alias, within the context of the source.


        :return: The name of this MonitoredResourceAliasCredential.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MonitoredResourceAliasCredential.
        The name of the alias, within the context of the source.


        :param name: The name of this MonitoredResourceAliasCredential.
        :type: str
        """
        self._name = name

    @property
    def credential(self):
        """
        **[Required]** Gets the credential of this MonitoredResourceAliasCredential.

        :return: The credential of this MonitoredResourceAliasCredential.
        :rtype: oci.stack_monitoring.models.MonitoredResourceAliasSourceCredential
        """
        return self._credential

    @credential.setter
    def credential(self, credential):
        """
        Sets the credential of this MonitoredResourceAliasCredential.

        :param credential: The credential of this MonitoredResourceAliasCredential.
        :type: oci.stack_monitoring.models.MonitoredResourceAliasSourceCredential
        """
        self._credential = credential

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PartitionConfig(object):
    """
    The information about partition configuration.
    """

    #: A constant which can be used with the model_type property of a PartitionConfig.
    #: This constant has a value of "KEYRANGEPARTITIONCONFIG"
    MODEL_TYPE_KEYRANGEPARTITIONCONFIG = "KEYRANGEPARTITIONCONFIG"

    def __init__(self, **kwargs):
        """
        Initializes a new PartitionConfig object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_connectivity.models.KeyRangePartitionConfig`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this PartitionConfig.
            Allowed values for this property are: "KEYRANGEPARTITIONCONFIG"
        :type model_type: str

        """
        self.swagger_types = {
            'model_type': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType'
        }

        self._model_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'KEYRANGEPARTITIONCONFIG':
            return 'KeyRangePartitionConfig'
        else:
            return 'PartitionConfig'

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this PartitionConfig.
        The type of partition configuration.

        Allowed values for this property are: "KEYRANGEPARTITIONCONFIG"


        :return: The model_type of this PartitionConfig.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this PartitionConfig.
        The type of partition configuration.


        :param model_type: The model_type of this PartitionConfig.
        :type: str
        """
        allowed_values = ["KEYRANGEPARTITIONCONFIG"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            raise ValueError(
                "Invalid value for `model_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._model_type = model_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FunctionSignature(object):
    """
    The function signature can specify function paramaters and/or function return type.
    """

    #: A constant which can be used with the model_type property of a FunctionSignature.
    #: This constant has a value of "DIS_FUNCTION_SIGNATURE"
    MODEL_TYPE_DIS_FUNCTION_SIGNATURE = "DIS_FUNCTION_SIGNATURE"

    def __init__(self, **kwargs):
        """
        Initializes a new FunctionSignature object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this FunctionSignature.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this FunctionSignature.
            Allowed values for this property are: "DIS_FUNCTION_SIGNATURE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this FunctionSignature.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this FunctionSignature.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this FunctionSignature.
        :type name: str

        :param ret_type:
            The value to assign to the ret_type property of this FunctionSignature.
        :type ret_type: oci.data_integration.models.ConfiguredType

        :param arguments:
            The value to assign to the arguments property of this FunctionSignature.
        :type arguments: list[oci.data_integration.models.TypedObject]

        :param description:
            The value to assign to the description property of this FunctionSignature.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this FunctionSignature.
        :type object_status: int

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'ret_type': 'ConfiguredType',
            'arguments': 'list[TypedObject]',
            'description': 'str',
            'object_status': 'int'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'ret_type': 'retType',
            'arguments': 'arguments',
            'description': 'description',
            'object_status': 'objectStatus'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._ret_type = None
        self._arguments = None
        self._description = None
        self._object_status = None

    @property
    def key(self):
        """
        Gets the key of this FunctionSignature.
        The key of the object.


        :return: The key of this FunctionSignature.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this FunctionSignature.
        The key of the object.


        :param key: The key of this FunctionSignature.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this FunctionSignature.
        The type of the object.

        Allowed values for this property are: "DIS_FUNCTION_SIGNATURE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The model_type of this FunctionSignature.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this FunctionSignature.
        The type of the object.


        :param model_type: The model_type of this FunctionSignature.
        :type: str
        """
        allowed_values = ["DIS_FUNCTION_SIGNATURE"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            model_type = 'UNKNOWN_ENUM_VALUE'
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this FunctionSignature.
        The model version of an object.


        :return: The model_version of this FunctionSignature.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this FunctionSignature.
        The model version of an object.


        :param model_version: The model_version of this FunctionSignature.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this FunctionSignature.

        :return: The parent_ref of this FunctionSignature.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this FunctionSignature.

        :param parent_ref: The parent_ref of this FunctionSignature.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this FunctionSignature.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this FunctionSignature.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FunctionSignature.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this FunctionSignature.
        :type: str
        """
        self._name = name

    @property
    def ret_type(self):
        """
        Gets the ret_type of this FunctionSignature.

        :return: The ret_type of this FunctionSignature.
        :rtype: oci.data_integration.models.ConfiguredType
        """
        return self._ret_type

    @ret_type.setter
    def ret_type(self, ret_type):
        """
        Sets the ret_type of this FunctionSignature.

        :param ret_type: The ret_type of this FunctionSignature.
        :type: oci.data_integration.models.ConfiguredType
        """
        self._ret_type = ret_type

    @property
    def arguments(self):
        """
        Gets the arguments of this FunctionSignature.
        An array of function arguments.


        :return: The arguments of this FunctionSignature.
        :rtype: list[oci.data_integration.models.TypedObject]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """
        Sets the arguments of this FunctionSignature.
        An array of function arguments.


        :param arguments: The arguments of this FunctionSignature.
        :type: list[oci.data_integration.models.TypedObject]
        """
        self._arguments = arguments

    @property
    def description(self):
        """
        Gets the description of this FunctionSignature.
        Detailed description for the object.


        :return: The description of this FunctionSignature.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this FunctionSignature.
        Detailed description for the object.


        :param description: The description of this FunctionSignature.
        :type: str
        """
        self._description = description

    @property
    def object_status(self):
        """
        Gets the object_status of this FunctionSignature.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this FunctionSignature.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this FunctionSignature.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this FunctionSignature.
        :type: int
        """
        self._object_status = object_status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NodePoolPlacementConfigDetails(object):
    """
    The location where a node pool will place nodes.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NodePoolPlacementConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this NodePoolPlacementConfigDetails.
        :type availability_domain: str

        :param subnet_id:
            The value to assign to the subnet_id property of this NodePoolPlacementConfigDetails.
        :type subnet_id: str

        :param capacity_reservation_id:
            The value to assign to the capacity_reservation_id property of this NodePoolPlacementConfigDetails.
        :type capacity_reservation_id: str

        :param fault_domains:
            The value to assign to the fault_domains property of this NodePoolPlacementConfigDetails.
        :type fault_domains: list[str]

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'subnet_id': 'str',
            'capacity_reservation_id': 'str',
            'fault_domains': 'list[str]'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'subnet_id': 'subnetId',
            'capacity_reservation_id': 'capacityReservationId',
            'fault_domains': 'faultDomains'
        }

        self._availability_domain = None
        self._subnet_id = None
        self._capacity_reservation_id = None
        self._fault_domains = None

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this NodePoolPlacementConfigDetails.
        The availability domain in which to place nodes.
        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this NodePoolPlacementConfigDetails.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this NodePoolPlacementConfigDetails.
        The availability domain in which to place nodes.
        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this NodePoolPlacementConfigDetails.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this NodePoolPlacementConfigDetails.
        The OCID of the subnet in which to place nodes.


        :return: The subnet_id of this NodePoolPlacementConfigDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this NodePoolPlacementConfigDetails.
        The OCID of the subnet in which to place nodes.


        :param subnet_id: The subnet_id of this NodePoolPlacementConfigDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def capacity_reservation_id(self):
        """
        Gets the capacity_reservation_id of this NodePoolPlacementConfigDetails.
        The OCID of the compute capacity reservation in which to place the compute instance.


        :return: The capacity_reservation_id of this NodePoolPlacementConfigDetails.
        :rtype: str
        """
        return self._capacity_reservation_id

    @capacity_reservation_id.setter
    def capacity_reservation_id(self, capacity_reservation_id):
        """
        Sets the capacity_reservation_id of this NodePoolPlacementConfigDetails.
        The OCID of the compute capacity reservation in which to place the compute instance.


        :param capacity_reservation_id: The capacity_reservation_id of this NodePoolPlacementConfigDetails.
        :type: str
        """
        self._capacity_reservation_id = capacity_reservation_id

    @property
    def fault_domains(self):
        """
        Gets the fault_domains of this NodePoolPlacementConfigDetails.
        A list of fault domains in which to place nodes.


        :return: The fault_domains of this NodePoolPlacementConfigDetails.
        :rtype: list[str]
        """
        return self._fault_domains

    @fault_domains.setter
    def fault_domains(self, fault_domains):
        """
        Sets the fault_domains of this NodePoolPlacementConfigDetails.
        A list of fault domains in which to place nodes.


        :param fault_domains: The fault_domains of this NodePoolPlacementConfigDetails.
        :type: list[str]
        """
        self._fault_domains = fault_domains

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_certificate_config_details import UpdateCertificateConfigDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateCertificateIssuedByInternalCaConfigDetails(UpdateCertificateConfigDetails):
    """
    The details for updating an internally managed certificate which is issued by a private certificate authority (CA).
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateCertificateIssuedByInternalCaConfigDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.certificates_management.models.UpdateCertificateIssuedByInternalCaConfigDetails.config_type` attribute
        of this class is ``ISSUED_BY_INTERNAL_CA`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param config_type:
            The value to assign to the config_type property of this UpdateCertificateIssuedByInternalCaConfigDetails.
            Allowed values for this property are: "ISSUED_BY_INTERNAL_CA", "MANAGED_EXTERNALLY_ISSUED_BY_INTERNAL_CA", "IMPORTED"
        :type config_type: str

        :param version_name:
            The value to assign to the version_name property of this UpdateCertificateIssuedByInternalCaConfigDetails.
        :type version_name: str

        :param stage:
            The value to assign to the stage property of this UpdateCertificateIssuedByInternalCaConfigDetails.
            Allowed values for this property are: "CURRENT", "PENDING"
        :type stage: str

        :param validity:
            The value to assign to the validity property of this UpdateCertificateIssuedByInternalCaConfigDetails.
        :type validity: oci.certificates_management.models.Validity

        """
        self.swagger_types = {
            'config_type': 'str',
            'version_name': 'str',
            'stage': 'str',
            'validity': 'Validity'
        }

        self.attribute_map = {
            'config_type': 'configType',
            'version_name': 'versionName',
            'stage': 'stage',
            'validity': 'validity'
        }

        self._config_type = None
        self._version_name = None
        self._stage = None
        self._validity = None
        self._config_type = 'ISSUED_BY_INTERNAL_CA'

    @property
    def validity(self):
        """
        Gets the validity of this UpdateCertificateIssuedByInternalCaConfigDetails.

        :return: The validity of this UpdateCertificateIssuedByInternalCaConfigDetails.
        :rtype: oci.certificates_management.models.Validity
        """
        return self._validity

    @validity.setter
    def validity(self, validity):
        """
        Sets the validity of this UpdateCertificateIssuedByInternalCaConfigDetails.

        :param validity: The validity of this UpdateCertificateIssuedByInternalCaConfigDetails.
        :type: oci.certificates_management.models.Validity
        """
        self._validity = validity

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DumpTransferDetails(object):
    """
    Optional additional properties for dump transfer.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DumpTransferDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source:
            The value to assign to the source property of this DumpTransferDetails.
        :type source: oci.database_migration.models.HostDumpTransferDetails

        :param target:
            The value to assign to the target property of this DumpTransferDetails.
        :type target: oci.database_migration.models.HostDumpTransferDetails

        """
        self.swagger_types = {
            'source': 'HostDumpTransferDetails',
            'target': 'HostDumpTransferDetails'
        }

        self.attribute_map = {
            'source': 'source',
            'target': 'target'
        }

        self._source = None
        self._target = None

    @property
    def source(self):
        """
        Gets the source of this DumpTransferDetails.

        :return: The source of this DumpTransferDetails.
        :rtype: oci.database_migration.models.HostDumpTransferDetails
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this DumpTransferDetails.

        :param source: The source of this DumpTransferDetails.
        :type: oci.database_migration.models.HostDumpTransferDetails
        """
        self._source = source

    @property
    def target(self):
        """
        Gets the target of this DumpTransferDetails.

        :return: The target of this DumpTransferDetails.
        :rtype: oci.database_migration.models.HostDumpTransferDetails
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this DumpTransferDetails.

        :param target: The target of this DumpTransferDetails.
        :type: oci.database_migration.models.HostDumpTransferDetails
        """
        self._target = target

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ChangeAnalyticsInstanceNetworkEndpointDetails(object):
    """
    Input payload to update an Analytics instance endpoint details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ChangeAnalyticsInstanceNetworkEndpointDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param network_endpoint_details:
            The value to assign to the network_endpoint_details property of this ChangeAnalyticsInstanceNetworkEndpointDetails.
        :type network_endpoint_details: oci.analytics.models.NetworkEndpointDetails

        """
        self.swagger_types = {
            'network_endpoint_details': 'NetworkEndpointDetails'
        }

        self.attribute_map = {
            'network_endpoint_details': 'networkEndpointDetails'
        }

        self._network_endpoint_details = None

    @property
    def network_endpoint_details(self):
        """
        **[Required]** Gets the network_endpoint_details of this ChangeAnalyticsInstanceNetworkEndpointDetails.

        :return: The network_endpoint_details of this ChangeAnalyticsInstanceNetworkEndpointDetails.
        :rtype: oci.analytics.models.NetworkEndpointDetails
        """
        return self._network_endpoint_details

    @network_endpoint_details.setter
    def network_endpoint_details(self, network_endpoint_details):
        """
        Sets the network_endpoint_details of this ChangeAnalyticsInstanceNetworkEndpointDetails.

        :param network_endpoint_details: The network_endpoint_details of this ChangeAnalyticsInstanceNetworkEndpointDetails.
        :type: oci.analytics.models.NetworkEndpointDetails
        """
        self._network_endpoint_details = network_endpoint_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RemoveDataFileDetails(object):
    """
    The details required to remove a data file or temp file from the tablespace.
    """

    #: A constant which can be used with the file_type property of a RemoveDataFileDetails.
    #: This constant has a value of "DATAFILE"
    FILE_TYPE_DATAFILE = "DATAFILE"

    #: A constant which can be used with the file_type property of a RemoveDataFileDetails.
    #: This constant has a value of "TEMPFILE"
    FILE_TYPE_TEMPFILE = "TEMPFILE"

    def __init__(self, **kwargs):
        """
        Initializes a new RemoveDataFileDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param credential_details:
            The value to assign to the credential_details property of this RemoveDataFileDetails.
        :type credential_details: oci.database_management.models.TablespaceAdminCredentialDetails

        :param file_type:
            The value to assign to the file_type property of this RemoveDataFileDetails.
            Allowed values for this property are: "DATAFILE", "TEMPFILE"
        :type file_type: str

        :param data_file:
            The value to assign to the data_file property of this RemoveDataFileDetails.
        :type data_file: str

        """
        self.swagger_types = {
            'credential_details': 'TablespaceAdminCredentialDetails',
            'file_type': 'str',
            'data_file': 'str'
        }

        self.attribute_map = {
            'credential_details': 'credentialDetails',
            'file_type': 'fileType',
            'data_file': 'dataFile'
        }

        self._credential_details = None
        self._file_type = None
        self._data_file = None

    @property
    def credential_details(self):
        """
        **[Required]** Gets the credential_details of this RemoveDataFileDetails.

        :return: The credential_details of this RemoveDataFileDetails.
        :rtype: oci.database_management.models.TablespaceAdminCredentialDetails
        """
        return self._credential_details

    @credential_details.setter
    def credential_details(self, credential_details):
        """
        Sets the credential_details of this RemoveDataFileDetails.

        :param credential_details: The credential_details of this RemoveDataFileDetails.
        :type: oci.database_management.models.TablespaceAdminCredentialDetails
        """
        self._credential_details = credential_details

    @property
    def file_type(self):
        """
        **[Required]** Gets the file_type of this RemoveDataFileDetails.
        Specifies whether the file is a data file or temp file.

        Allowed values for this property are: "DATAFILE", "TEMPFILE"


        :return: The file_type of this RemoveDataFileDetails.
        :rtype: str
        """
        return self._file_type

    @file_type.setter
    def file_type(self, file_type):
        """
        Sets the file_type of this RemoveDataFileDetails.
        Specifies whether the file is a data file or temp file.


        :param file_type: The file_type of this RemoveDataFileDetails.
        :type: str
        """
        allowed_values = ["DATAFILE", "TEMPFILE"]
        if not value_allowed_none_or_none_sentinel(file_type, allowed_values):
            raise ValueError(
                "Invalid value for `file_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._file_type = file_type

    @property
    def data_file(self):
        """
        **[Required]** Gets the data_file of this RemoveDataFileDetails.
        Name of the data file or temp file to be removed from the tablespace.


        :return: The data_file of this RemoveDataFileDetails.
        :rtype: str
        """
        return self._data_file

    @data_file.setter
    def data_file(self, data_file):
        """
        Sets the data_file of this RemoveDataFileDetails.
        Name of the data file or temp file to be removed from the tablespace.


        :param data_file: The data_file of this RemoveDataFileDetails.
        :type: str
        """
        self._data_file = data_file

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnnotationAnalyticsAggregation(object):
    """
    Aggregation entities are required by the API consistency guidelines for API Consistency Guidelines#AnalyticsAPIs.  These are used to summarize annotations for a given dataset and will be used to populate UI elements.  Aggregations need to have the fields that identify the exact scope that they're summarizing.  Any filters applied to the list API, have to show up in the aggregation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AnnotationAnalyticsAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param count:
            The value to assign to the count property of this AnnotationAnalyticsAggregation.
        :type count: float

        :param dataset_id:
            The value to assign to the dataset_id property of this AnnotationAnalyticsAggregation.
        :type dataset_id: str

        :param dimensions:
            The value to assign to the dimensions property of this AnnotationAnalyticsAggregation.
        :type dimensions: oci.data_labeling_service_dataplane.models.AnnotationAggregationDimensions

        :param updated_by:
            The value to assign to the updated_by property of this AnnotationAnalyticsAggregation.
        :type updated_by: str

        :param compartment_id:
            The value to assign to the compartment_id property of this AnnotationAnalyticsAggregation.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this AnnotationAnalyticsAggregation.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'count': 'float',
            'dataset_id': 'str',
            'dimensions': 'AnnotationAggregationDimensions',
            'updated_by': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'count': 'count',
            'dataset_id': 'datasetId',
            'dimensions': 'dimensions',
            'updated_by': 'updatedBy',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState'
        }

        self._count = None
        self._dataset_id = None
        self._dimensions = None
        self._updated_by = None
        self._compartment_id = None
        self._lifecycle_state = None

    @property
    def count(self):
        """
        **[Required]** Gets the count of this AnnotationAnalyticsAggregation.
        The count of the matching results.


        :return: The count of this AnnotationAnalyticsAggregation.
        :rtype: float
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this AnnotationAnalyticsAggregation.
        The count of the matching results.


        :param count: The count of this AnnotationAnalyticsAggregation.
        :type: float
        """
        self._count = count

    @property
    def dataset_id(self):
        """
        **[Required]** Gets the dataset_id of this AnnotationAnalyticsAggregation.
        The OCID of the dataset the annotations belong to.


        :return: The dataset_id of this AnnotationAnalyticsAggregation.
        :rtype: str
        """
        return self._dataset_id

    @dataset_id.setter
    def dataset_id(self, dataset_id):
        """
        Sets the dataset_id of this AnnotationAnalyticsAggregation.
        The OCID of the dataset the annotations belong to.


        :param dataset_id: The dataset_id of this AnnotationAnalyticsAggregation.
        :type: str
        """
        self._dataset_id = dataset_id

    @property
    def dimensions(self):
        """
        Gets the dimensions of this AnnotationAnalyticsAggregation.

        :return: The dimensions of this AnnotationAnalyticsAggregation.
        :rtype: oci.data_labeling_service_dataplane.models.AnnotationAggregationDimensions
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this AnnotationAnalyticsAggregation.

        :param dimensions: The dimensions of this AnnotationAnalyticsAggregation.
        :type: oci.data_labeling_service_dataplane.models.AnnotationAggregationDimensions
        """
        self._dimensions = dimensions

    @property
    def updated_by(self):
        """
        Gets the updated_by of this AnnotationAnalyticsAggregation.
        The OCID of the principal which updated the annotation.


        :return: The updated_by of this AnnotationAnalyticsAggregation.
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """
        Sets the updated_by of this AnnotationAnalyticsAggregation.
        The OCID of the principal which updated the annotation.


        :param updated_by: The updated_by of this AnnotationAnalyticsAggregation.
        :type: str
        """
        self._updated_by = updated_by

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this AnnotationAnalyticsAggregation.
        The OCID of the compartment containing the annotations.


        :return: The compartment_id of this AnnotationAnalyticsAggregation.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AnnotationAnalyticsAggregation.
        The OCID of the compartment containing the annotations.


        :param compartment_id: The compartment_id of this AnnotationAnalyticsAggregation.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this AnnotationAnalyticsAggregation.
        Describes the lifecycle state.


        :return: The lifecycle_state of this AnnotationAnalyticsAggregation.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this AnnotationAnalyticsAggregation.
        Describes the lifecycle state.


        :param lifecycle_state: The lifecycle_state of this AnnotationAnalyticsAggregation.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
